@@ -45,6 +45,10 @@
 #include <math.h>
 #include <time.h>
 
+#ifdef HAVE_KEXIV2
+#include <libkexiv2/kexiv2.h>
+#endif
+
 #include "slideshow.h"
 #include "slideshow.moc"
 
@@ -155,7 +159,7 @@ void kSlideShowSaver::readConfig()
   mShowRandom = config.readEntry("ShowRandom", true);
   mZoomImages = config.readEntry("ZoomImages", false);
   mPrintName = config.readEntry("PrintName", true);
-  mDirectory = config.readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", "").last());
+  mDirectory = config.readPathEntry("Directory", KGlobal::dirs()->findDirs("wallpaper", QLatin1String( "" )).last());
   mDelay = config.readEntry("Delay", 10) * 1000;
   mSubdirectory = config.readEntry("SubDirectory", false);
   mRandomPosition = config.readEntry("RandomPosition", false);
@@ -878,6 +882,11 @@ nexttry:
   }
   mFileIdx++;
 
+#ifdef HAVE_KEXIV2
+  KExiv2Iface::KExiv2 exiv(fname);
+  exiv.rotateExifQImage(mImage, exiv.getImageOrientation());
+#endif
+
   mImageName = QFileInfo(fname).baseName();
 }
 
@@ -904,7 +913,7 @@ void kSlideShowSaver::traverseDirectory(const QString &dirName)
   QFileInfoList::Iterator it = fileinfolist.begin();
   while ( it != fileinfolist.end())
   {
-     if (it->fileName() == "." || it->fileName() == "..")
+     if (it->fileName() == QLatin1String( "." ) || it->fileName() == QLatin1String( ".." ))
      {
         ++it;
         continue;
@@ -970,7 +979,7 @@ void kSlideShowSetup::readSettings()
     cfg->mCbxShowName->setChecked(config.readEntry("PrintName", true));
     cfg->mDelay->setValue(config.readEntry("Delay", 20));
     cfg->mDelay->setSuffix(ki18np(" second", " seconds"));
-    cfg->mDirChooser->setPath(config.readPathEntry("Directory", QString()));
+    cfg->mDirChooser->setUrl(KUrl(config.readPathEntry("Directory", QString())));
     cfg->mCbxSubdirectory->setChecked(config.readEntry("SubDirectory", false));
     cfg->mCbxRandomPosition->setChecked(config.readEntry("RandomPosition", false));
 }
